@@ -37,6 +37,12 @@ def pytask_extend_command_line_interface(cli):
             ),
             metavar="module_name:class_name",
         ),
+        click.Option(
+            ["--show-locals"],
+            is_flag=True,
+            default=None,
+            help="Show local variables in tracebacks.",
+        ),
     ]
     cli.commands["build"].params.extend(additional_parameters)
 
@@ -65,6 +71,13 @@ def pytask_parse_config(config, config_from_cli, config_from_file):
         default=None,
         callback=_pdbcls_callback,
     )
+    config["show_locals"] = get_first_non_none_value(
+        config_from_cli,
+        config_from_file,
+        key="show_locals",
+        default=False,
+        callback=convert_truthy_or_falsy_to_bool,
+    )
 
 
 def _pdbcls_callback(x):
@@ -106,6 +119,17 @@ def pytask_post_parse(config):
     PytaskPDB._config = config
 
 
+@hookimpl
+def pytask_unconfigure():
+    """Return the resources.
+
+    If the :func:`pdb.set_trace` function would not be returned, using breakpoints in
+    test functions with pytask would fail.
+
+    """
+    pdb.set_trace, _, _ = PytaskPDB._saved.pop()
+
+
 class PytaskPDB:
     """Pseudo PDB that defers to the real pdb."""
 
@@ -183,18 +207,11 @@ class PytaskPDB:
                     capman = self._pytask_capman
                     capturing = PytaskPDB._is_capturing(capman)
                     if capturing:
-                        if capturing == "global":
-                            console.rule(
-                                "PDB continue (IO-capturing resumed)",
-                                characters=">",
-                                style=None,
-                            )
-                        else:
-                            console.rule(
-                                f"PDB continue (IO-capturing resumed for {capturing})",
-                                characters=">",
-                                style=None,
-                            )
+                        console.rule(
+                            "PDB continue (IO-capturing resumed)",
+                            characters=">",
+                            style=None,
+                        )
                         assert capman is not None
                         capman.resume()
                     else:
@@ -269,18 +286,12 @@ class PytaskPDB:
                     console.rule(header, characters=">", style=None)
                 else:
                     capturing = cls._is_capturing(capman)
-                    if capturing == "global":
+                    if capturing:
                         console.rule(
                             f"PDB {method} (IO-capturing turned off)",
                             characters=">",
                             style=None,
                         )
-                    elif capturing:
-                        console.rule(
-                            f"PDB {method} (IO-capturing turned off for {capturing})",
-                            characters=">",
-                            style=None,
-                        )
                     else:
                         console.rule(f"PDB {method}", characters=">", style=None)
 
